/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.headless.portal.instances.internal.jaxrs.exception.mapper;

import com.liferay.portal.kernel.exception.CompanyWebIdException;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * Converts any {@code CompanyWebIdException} to a {@code 400} error.
 *
 * @author Alberto Chaparro
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Portal.Instances)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Portal.Instances.PortalInstancePortalInstanceIdExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class PortalInstancePortalInstanceIdExceptionMapper
	extends BaseExceptionMapper<CompanyWebIdException> {

	@Override
	protected Problem getProblem(CompanyWebIdException companyWebIdException) {
		return new Problem(
			Response.Status.BAD_REQUEST,
			StringUtil.replace(
				companyWebIdException.getMessage(),
				new String[] {"Web ID", "web ID"},
				new String[] {"Portal instance ID", "portal instance ID"}));
	}

}